==> sgwi-0.7.tbz: www/sgwi/awl_delete_undef.php <==
<?
	require "config.inc.php";
	require "db.inc.php";
	require "tools.inc.php";

	if ($_GET["mode"] == "email")
		$mode = 1;
	else
		$mode = 0;
?>
<HTML>
<HEAD>
<TITLE>Whitelisted <? if ($mode) print "e-mail addresses"; else print "domains"; ?>, delete '-undef-' entries</TITLE>
<BODY>
<TABLE WIDTH=100% HEIGHT=100%><TR VALIGN=CENTER><TD ALIGN=CENTER>

<H1>Whitelisted <? if ($mode) print "e-mail addresses"; else print "domains"; ?>, delete '-undef-' entries</H1>

<?
# mysql> describe from_awl;
# +---------------+---------------+------+-----+----------------+-------+
# | Field         | Type          | Null | Key | Default        | Extra |
# +---------------+---------------+------+-----+----------------+-------+
# | sender_name   | varchar(64)   |      | PRI |                |       |
# | sender_domain | varchar(255)  |      | PRI |                |       |
# | src           | varchar(39)   |      | PRI |                |       |
# | first_seen    | timestamp(14) | YES  |     | NULL           |       |
# | last_seen     | timestamp(14) | YES  | MUL | 00000000000000 |       |
# +---------------+---------------+------+-----+----------------+-------+
# 5 rows in set (0.00 sec)

# mysql> describe domain_awl;
# +---------------+---------------+------+-----+----------------+-------+
# | Field         | Type          | Null | Key | Default        | Extra |
# +---------------+---------------+------+-----+----------------+-------+
# | sender_domain | varchar(255)  |      | PRI |                |       |
# | src           | varchar(39)   |      | PRI |                |       |
# | first_seen    | timestamp(14) | YES  |     | NULL           |       |
# | last_seen     | timestamp(14) | YES  | MUL | 00000000000000 |       |
# +---------------+---------------+------+-----+----------------+-------+
# 4 rows in set (0.00 sec)
?>

<?
	if ($mode)
		$query = "DELETE FROM from_awl WHERE sender_name='-undef-' AND sender_domain='-undef-'";
	else
		$query = "DELETE FROM domain_awl WHERE sender_domain='-undef-'";
	$result = do_query($query);
?>
'-undef-' entries deleted.
<BR>
<BR>

<A HREF="awl.php?mode=<? print $_GET["mode"]; ?>">Whitelisted <? if ($mode) print "e-mail addresses"; else print "domains"; ?> menu</A><BR>
<A HREF="index.php">Main menu</A><BR>

<BR>
<BR>

</TD></TR>

<? require "copyright.inc.php" ?>

</TABLE>
</BODY>
</HTML>

==> sgwi-0.8.tbz: www/sgwi/awl_delete_undef.php <==
<?php
	require "config.inc.php";
	require "db.inc.php";
	require "tools.inc.php";

	if ($_GET["mode"] == "email")
		$mode = 1;
	else
		$mode = 0;
?>
<HTML>
<HEAD>
<TITLE>Whitelisted <?php if ($mode) print "e-mail addresses"; else print "domains"; ?>, delete '-undef-' entries</TITLE>
<BODY>
<TABLE WIDTH=100% HEIGHT=100%><TR VALIGN=CENTER><TD ALIGN=CENTER>

<H1>Whitelisted <?php if ($mode) print "e-mail addresses"; else print "domains"; ?>, delete '-undef-' entries</H1>

<?php
# mysql> describe from_awl;
# +---------------+---------------+------+-----+----------------+-------+
# | Field         | Type          | Null | Key | Default        | Extra |
# +---------------+---------------+------+-----+----------------+-------+
# | sender_name   | varchar(64)   |      | PRI |                |       |
# | sender_domain | varchar(255)  |      | PRI |                |       |
# | src           | varchar(39)   |      | PRI |                |       |
# | first_seen    | timestamp(14) | YES  |     | NULL           |       |
# | last_seen     | timestamp(14) | YES  | MUL | 00000000000000 |       |
# +---------------+---------------+------+-----+----------------+-------+
# 5 rows in set (0.00 sec)

# mysql> describe domain_awl;
# +---------------+---------------+------+-----+----------------+-------+
# | Field         | Type          | Null | Key | Default        | Extra |
# +---------------+---------------+------+-----+----------------+-------+
# | sender_domain | varchar(255)  |      | PRI |                |       |
# | src           | varchar(39)   |      | PRI |                |       |
# | first_seen    | timestamp(14) | YES  |     | NULL           |       |
# | last_seen     | timestamp(14) | YES  | MUL | 00000000000000 |       |
# +---------------+---------------+------+-----+----------------+-------+
# 4 rows in set (0.00 sec)
?>

<?php
	if ($mode)
		$query = "DELETE FROM from_awl WHERE sender_name='-undef-' AND sender_domain='-undef-'";
	else
		$query = "DELETE FROM domain_awl WHERE sender_domain='-undef-'";
	$result = do_query($query);
?>
'-undef-' entries deleted.
<BR>
<BR>

<A HREF="awl.php?mode=<?php print $_GET["mode"]; ?>">Whitelisted <?php if ($mode) print "e-mail addresses"; else print "domains"; ?> menu</A><BR>
<A HREF="index.php">Main menu</A><BR>

<BR>
<BR>

</TD></TR>

<?php require "copyright.inc.php" ?>

</TABLE>
</BODY>
</HTML>
